Summary: The LDM is a distributed system for event-driven data distribution. It consists of a suite of software to select, capture, process, and distribute data products using a set of network client/server programs and their shared protocols. 
Name: ldm
Version: 6.6.4
Release: 1.RHE4
License: Copyright 1996-2003 University Corporation for Atmospheric Research/Unidata
Group: Applications/Internet
URL: http://my.unidata.ucar.edu/content/software/ldm
Source0: %{name}-%{version}.tar.gz
Source1: .bashrc
Source2: .bash_profile
Source3: ldmd
Source4: ldm.cron
Patch0: macros.make.in.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
%define LdmHome /usr/local/ldm

%description
Unidata's Local Data Manager (LDM) software acquires data and shares them with other networked computers. A data product is treated as a opaque unit, thus nearly any data can be relayed. In particular, the LDM can handle data from National Weather Service "NOAAport channel 3" data streams, including gridded data from the numerical forecast models. It also handles NEXRAD radar data, lightning data from the National Lightning Detection Network, and GOES satellite imagery.

Data can either be ingested directly from a data source by a client ingester, or the LDM server can talk to other LDM servers to either receive or send data. Ingesters scan the data stream, determine product boundaries, and extract products, passing those products on to the server product queue. These data, in turn, can be processed locally and/or passed on to other LDM servers.

Data passed to the LDM server are processed in a variety of ways; how specific data are processed is determined by data identifiers and a configuration file. Processing actions include placing the data in files and running arbitrary programs on the data. Decoders are also available from Unidata that interface with the LDM and convert data into the forms required by various applications.

Features:

    * User configurable: The LDM server can be instructed to append a particular product to a file; execute an arbitrary program with the data product as input; store or retrieve products in a simple key-access database; or forward the data along to other running servers.
    * Supports distributed processing: Data captured on one machine can be stored on other machines on a network. This means that data ingest functions can be separated from storage and use functions. LDM servers may also be configured to relay subsets of data among themselves, distributing the storage and processing around the network.
    * Extensible: New decoders can be added easily, including decoders for archival data.
    * Event-driven: Handles data as it arrives. 

%package devel
Summary: The developer interface for creating programs and libraries that use the %name library.

Group: Development/Libraries

%description devel
The %name-devel package contains the libraries and header files
needed for development of programs and libraries that use the %name library.

%prep

%setup -q
%patch0

%build
export LDMHOME=%{LdmHome}
cd src
./configure prefix=$RPM_BUILD_ROOT%{LdmHome}
make

%install
rm -rf $RPM_BUILD_ROOT
export LDMHOME=%{LdmHome}
cd src
/usr/bin/install -d $RPM_BUILD_ROOT%{LdmHome}
make install
/usr/bin/install -d $RPM_BUILD_ROOT/var/data/ldm/logs
touch $RPM_BUILD_ROOT/var/data/ldm/logs/ldmd.log
/usr/bin/install -d $RPM_BUILD_ROOT%{LdmHome}/doc
/usr/bin/install -d $RPM_BUILD_ROOT%{LdmHome}/decoders
/usr/bin/install -d $RPM_BUILD_ROOT%{LdmHome}/util
/usr/bin/install -d $RPM_BUILD_ROOT/etc/rc.d/init.d
/usr/bin/install -d $RPM_BUILD_ROOT/etc/cron.daily
/usr/bin/install %{SOURCE1} $RPM_BUILD_ROOT%{LdmHome}
/usr/bin/install %{SOURCE2} $RPM_BUILD_ROOT%{LdmHome}
/usr/bin/install %{SOURCE3} $RPM_BUILD_ROOT/etc/rc.d/init.d
/usr/bin/install %{SOURCE4} $RPM_BUILD_ROOT/etc/cron.daily

%clean
rm -rf $RPM_BUILD_ROOT

%pre
groupadd wxman 2>/dev/null || :
useradd ldm -g wxman -d %{LdmHome} 2>/dev/null || :

%post
/sbin/chkconfig --add ldmd
rm -f %{LdmHome}/logs
ln -s /var/data/ldm/logs %{LdmHome}/logs 2>/dev/null || :
rm -f %{LdmHome}/data
ln -s /var/data/ldm %{LdmHome}/data 2>/dev/null || :
retval=`grep -c "ldm" /etc/services`

if [ $retval -eq 0 ];
then
   echo "ldm 388/tcp ldmd  #UCAR Unidata LDM" >> /etc/services
fi

retval=`grep -c "ldm" /etc/rpc`

if [ $retval -eq 0 ];
then
   echo "ldm    300029     ldmd" >> /etc/rpc
fi

retval=`grep -c "ldm" /etc/syslog.conf`

if [ $retval -eq 0 ];
then
   echo "" >> /etc/syslog.conf
   echo "# Setup logging for LDM" >> /etc/syslog.conf
   echo "local0.debug /var/data/ldm/logs/ldmd.log" >> /etc/syslog.conf
   service syslog restart
fi

if [ $1 = 1 ]; then
    su - ldm -c "%{LdmHome}/bin/ldmadmin mkqueue"
fi

%preun
if [ $1 = 0 ]; then
    /sbin/service ldmd stop > /dev/null 2>&1
    /sbin/chkconfig --del ldmd
    su - ldm -c "%{LdmHome}/bin/ldmadmin delqueue"
    rm -f %{LdmHome}/logs
    rm -f %{LdmHome}/data
fi

%postun
if [ "$1" -ge "1" ]; then
    /sbin/service ldmd condrestart > /dev/null 2>&1
fi

%files
%defattr(-,ldm,wxman,-)
%dir %{LdmHome}
%dir %{LdmHome}/bin
%{LdmHome}/bin/afos
%{LdmHome}/bin/ddplus
%{LdmHome}/bin/dds
%{LdmHome}/bin/feedme
%{LdmHome}/bin/feedtest
%{LdmHome}/bin/hds
%{LdmHome}/bin/hrs
%attr(4755,root,root) %{LdmHome}/bin/hupsyslog
%{LdmHome}/bin/ids
%{LdmHome}/bin/ldmadmin
%{LdmHome}/bin/ldmcheck
%{LdmHome}/bin/ldmfail
%{LdmHome}/bin/ldmping
%{LdmHome}/bin/ldmsend
%{LdmHome}/bin/netcheck
%{LdmHome}/bin/newlog
%{LdmHome}/bin/notifyme
%{LdmHome}/bin/pps
%{LdmHome}/bin/pqact
%{LdmHome}/bin/pqcat
%{LdmHome}/bin/pqcheck
%{LdmHome}/bin/pqcreate
%{LdmHome}/bin/pqexpire
%{LdmHome}/bin/pqing
%{LdmHome}/bin/pqinsert
%{LdmHome}/bin/pqmon
%{LdmHome}/bin/pqsend
%{LdmHome}/bin/pqsurf
%{LdmHome}/bin/pqutil
%{LdmHome}/bin/regex
%attr(4775,root,root) %{LdmHome}/bin/rpc.ldmd
%{LdmHome}/bin/rtstats
%{LdmHome}/bin/scour
%{LdmHome}/bin/scriptconfig
%{LdmHome}/bin/syscheck
%dir %{LdmHome}/decoders
%dir %{LdmHome}/util
%dir %{LdmHome}/etc
%config(noreplace) %{LdmHome}/etc/*
%dir %{LdmHome}/man
%dir %{LdmHome}/man/man1
%docdir %{LdmHome}/man/man1
%docdir %{LdmHome}/doc
%{LdmHome}/man/man1/*
%attr(775,ldm,wxman) %dir /var/data/ldm
%attr(775,ldm,wxman) %dir /var/data/ldm/logs
/var/data/ldm/logs/*
%{LdmHome}/.bashrc
%{LdmHome}/.bash_profile
%config /etc/rc.d/init.d/ldmd
%config /etc/cron.daily

%files devel
%defattr(-,ldmd,wxman,-)
%dir %{LdmHome}/include
%{LdmHome}/include/*
%dir %{LdmHome}/lib
%{LdmHome}/lib/*
%dir %{LdmHome}/man
%dir %{LdmHome}/man/man3
%docdir %{LdmHome}/man/man3
%{LdmHome}/man/man3/*

%changelog
* Tue Oct 18 2005 Glenn Zickert <glenn.a.zickert@lmco.com>
- Added Log rotate, ldm.cron to /etc/cron.daily.
* Tue Aug 9 2005 Glenn Zickert <glenn.a.zickert@lmco.com>
- Initial build.

